@@ -84,6 +84,25 @@ def get_up_info(uid: int, verify: utils.Verify = None):
     return data
 
 
+def get_user_card(uid: int, verify: utils.Verify = None):
+    """
+    获取用户名片信息（头像，粉丝数）
+    :param uid:
+    :param verify:
+    :return:
+    """
+    if verify is None:
+        verify = utils.Verify()
+
+    api = API["user"]["info"]["card"]
+    params = {
+        "mid": uid,
+        "photo": '1',
+    }
+    data = utils.get(url=api["url"], params=params, cookies=verify.get_cookies())
+    return data
+
+  
 def get_live_info(uid: int, verify: utils.Verify = None):
     """
     获取用户直播间信息
